# ChangeLog

### 0.7.45
- ADDED: 	mptsec is also available as PIP package

### 0.7.42
- CHANGE: 	Changed mpt package name to mptsec

### 0.7.41
- CHANGE: 	Added symlinks to available binaries and global TMP_BIN folder

### 0.7.40
- CHANGE: 	Minor fix

### 0.7.39
- ADDED: 	Select and download frida version running on device

### 0.7.38
- CHANGE: 	Fixed fridump

### 0.7.37
- CHANGE: 	Updated fridump

### 0.7.36
- CHANGE: 	Minor fix

### 0.7.35
- CHANGE: 	tool objection

### 0.7.34
- BUGFIX: 	fixed issue with special chars in apk filename 
- ADDED: 	new pentest folder structure

### 0.7.33
- CHANGE: 	Minor changes

### 0.7.32
- CHANGE: 	Default application folder and configuration file

### 0.7.31
- ADDED: 	Application label

### 0.7.30
- BUGFIX: 	source import of bash files

### 0.7.29
- BUGFIX: 	Fixed command execution on bash und zsh

### 0.7.28
- BUGFIX: 	MobSF Installation and start

### 0.7.27
- BUGFIX: 	MobSF Installation and start
- BUGFIX: 	Tool objection 

### 0.7.26
- ADDED: 	scrcpy (This application mirrors Android devices (video and audio) connected via USB)

### 0.7.25
- CHANGE: 	Updated command execution

### 0.7.24
- BUGFIX: 	Fixed bug mobSF

### 0.7.23
- BUGFIX: 	Fixed bug mobSF installation

### 0.7.22
- ADDED: 	poetry dependency

### 0.7.21
- CHANGE: 	new stable version

### 0.7.20
- BUGFIX: 	Fixed format bug

### 0.7.19
- CHANGE: 	Min. python version 3.9

### 0.7.18
- ADDED: 	Option to take screenshot from device 

### 0.7.17
- ADDED: 	Added a static IP option for access point

### 0.7.16
- ADDED: 	Added option to create Hotspot for proxy (AP)

### 0.7.15
- CHANGE: 	Updated README
- BUGFIX: 	Fix installation issue

### 0.7.14
- CHANGE: 	WiFi module have separate commands for enabling and disabling proxy
- CHANGE: 	Updated bypass SSL-pinning script
- ADDED: 	Local installation for tools, tools can be installed via command-line
- BUGFIX: 	RMS installation via npm
- REMOVED: 	Blob apk files

### 0.7.13
- CHANGE: 	Updated supported tools 
- CHANGE: 	Refactored menu options

### 0.7.12
- ADDED: 	Requirement application check before tool installation

### 0.7.11
- CHANGE: 	Updated package listing
- CHANGE:   Some minor changes

### 0.7.10
- CHANGE: 	Updated zsh plugin
- CHANGE:   Some minor changes

### 0.7.9
- BUGFIX: 	Fixed load config and listing device issues 
- CHANGE:   Updated installation process --update flag

### 0.7.8
- ADDED: 	Update to the latest version from cli
- BUGFIX: 	Backup function  

### 0.7.7
- ADDED: 	added tool kitty (terminal emulator)
- CHANGE:   Setup pentest project
- BUGFIX: 	fixed install_http  

### 0.7.6
- ADDED: 	tool objection added
- ADDED: 	Moved from static setting.MOBILE_FOLDER to dynamic install-dir    

### 0.7.5
- ADDED: 	additional arguments can be passed to tool parameter ---tool  

### 0.7.4
- ADDED: 	Configuration file format was switched to json 
- CHANGE:	README
- CHANGE:	Refactoring

### 0.7.3
- ADDED: 	Migrated to pyproject.toml
- BUGFIX: 	load frida scripts

### 0.7.2
- ADDED: 	pipx installation support
- CHANGE:	README
- BUGFIX: 	wi-fi proxy switch
- BUGFIX: 	frida-server upload
- BUGFIX: 	fridump

### 0.7.1
- ADDED: 	'decompile' option

### 0.7.0
- ADDED: 	'tool' parameter and available tool listing
- ADDED: 	dex2jar tool
- CHANGE:	Installation process for git and http file download
- REMOVED:	removed MobSF parameter

### 0.6.3
- ADDED: 	http download from single and archive files
- ADDED: 	jadx tool
- ADDED: 	ChangeLog
- CHANGE: 	Updated URLs for locally installed tools
- BUGFIX: 	multiple minor bug fixes
- BUGFIX: 	MobSF installation and execution

